class adellist(list):
    
    def __init__(self,*arg):
        super().__init__(arg)
    def get(self):#get the values in adellist
        return self
    def elements(self,up=0,down=1):#get list[int:int]
        return self[up:down]
    def add(self,text=None):#add one value into the list
        self.append(text)
        return self
    def addelems(self,*arg):#add values into the list
        for i in arg:
            self.append(i)
    def sort(self,error=False,reverse=False,error_text=True):#sort the list(int list)
        try:
            super().sort(reverse=reverse)
        except TypeError as e:
            if error:
                if not error_text:
                    raise TypeError(e)
                else:
                    print(e)
    #def pop(self,index=-1):#remove one value from the list
    #    super().pop(index)
    #def clear(self):#clear th list
    #    super().clear()
    #def remove(self,value,error=True):
    #    try:
    #        super().remove(value)
    #    except ValueError as v:
    #        if error:
    #            raise ValueError(v)
    #def copy(self):
    #    return self.copy()


class readerlist(list):
    def __init__(self,*arg):
        super().__init__(arg)
    def get(self):
        return self
    def add(self,text=None):
        self.append(text)
        return self
    #def pop(self,index=-1):
    #    self.pop(index)
    #def clear(self):
    #    self.clear()
    def __find(self,value,times=1):
        lst=[]
        list2=self.copy()
        for i in list2:
            times-=1
            if i==value:
                lst.append(self.index(i))
                list2[list2.index(i)]=str(value)+'iscoded'
            if times==0:break
        return lst
    def count(self,value):
        n=0
        for i in self:
            if i==value:
                n+=1
        return n
    #def copy(self):
    #    return self.copy()

class queue():
    def __init__(self):
        self.__text=[]
    def push(self,s):
        self.__text.append(s)
    def size(self):
        return len(self.__text)
    def front(self):
        class qError(Exception):
            def __init__(self,e):
                super().__init__(e)
    
        if self.size()>0:
            return self.__text[0]
        else:
            raise qError('QueueIsEmptyError:Queue is empty.Please use push before using front()')
    def pop(self):
        if self.size()>0:
            self.__text.pop(0)
        else:
            class qError(Exception):
                def __init__(self,e):
                    super().__init__(e)
            raise qError('QueueIsEmptyError:Queue is empty.Please use push before using pop()')

class stack():
    def __init__(self):
        self.__text=[]
    def push(self,s):
        self.__text.append(s)
    def size(self):
        return len(self.__text)
    def top(self):
        class sError(Exception):
            def __init__(self,e):
                super().__init__(e)
    
        if self.size()>0:
            return self.__text[len(self.__text)-1]
        else:
            raise sError('StackIsEmptyError:Stack is empty.Please use push before using top()')
    def pop(self):
        if self.size()>0:
            self.__text.pop(len(self.__text)-1)
        else:
            class sError(Exception):
                def __init__(self,e):
                    super().__init__(e)
            raise sError('StackIsEmptyError:Stack is empty.Please use push before using pop()')

        



class File():
    def __init__(self,name,way='.'):
        self.name=way+'\\'+name
    def write(self,text=''):
        f=open(self.name,'w')
        f.write(text)
        f.close()
    def create(self):
        f=open(self.name,'w')
        f.close()
    def addtext(self,text=''):
        f=open(self.name,'a')
        f.write(text)
        f.close()
    def remove(self,value='',times=1):
        f=open(self.name,'r+')
        text=f.read()
        f.close()
        for i in text:
            times-=1
            if i==value:
                text.replace(i,'')
            if times==0:
                break
        f=open(self.name,'w')
        f.write(text)
        f.close()
    def read(self):
        f=open(self.name,'r')
        txt=f.read()
        f.close()
        return txt
    def __pop(self,times=1):
        f=open(self.name,'r+')
        txt=f.read()
        lst=list(txt)
        for i in range(0,times+1):
            lst.pop()
        txt=str(lst)
        f.write(txt)
        f.close()
def write(file,text='',way='.'):
    f=open(way+'\\'+file,'w')
    f.write(text)
    f.close()
def addtext(self,text=''):
    f=open(self.name,'a')
    f.write(text)
    f.close()
def remove(self,value='',times=1):
    f=open(self.name,'r+')
    text=f.read()
    for i in text:
        times-=1
        if i==value:
            text.replace(i,'')
        if times==0:
            break
def read(self):
    f=open(self.name,'r')
    txt=f.read()
    f.close()
    return txt



import setuptools

with open('README.md','r') as f:
    long_description=f.read()

setuptools.setup(
    name='asptl',
    version='1.0.0',
    author='Amir',
    author_email='hi-amir@outlook.com',
    url='pypi.org',
    description='''
Exclusively developed by AmirSong (pypi)

It encapsulates many common components

Including file read-write list, etc''',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Imdependent',
    ],)



from threading import*
from time import sleep

mypybag_clocks=[]
mypybag_threads=[]

class clock(Thread):
    def __init__(self,command,time=1/60):
        super().__init__(target=command)
        self.time=time
        self.target=command
        self.d=False
    def run(self):
        while True:
            if self.d:
                break
            sleep(self.time)
            self.target()
    def dead(self):
        self.d=True
            
def add_schedule(command,time=1/60):
    mypybag_clocks.append(clock(command,time))

def run_schedule():
    for c in mypybag_clocks:
        c.start()
    for c in mypybag_clocks:
        c.join()
def stop_all_schedule():
    for c in mypybag_clocks:
        c.dead()

class threading(Thread):
    def __init__(self,command):
        super().__init__(target=command)
        self.target=command
        self.d=False
    def run(self):
        self.target()

def add_thread(command):
    mypybag_threads.append(threading(command))

def run_thread():
    for t in mypybag_threads:
        t.start()

def run():
    for t in mypybag_threads:
        t.start()
    for c in mypybag_clocks:
        c.start()
    for c in mypybag_clocks:
        c.join()

def cancel():
    mypybag_threads.clear()
    mypybag_clocks.clear()

def cancel_schedule():
    mypybag_clocks.clear()

def cancel_thread():
    mypybag_threads.clear()



from tkinter import*
def msgwin(caption='',ExitButton='OK',MainLabel='please...',buttons=[],labels=[],loop=True):
    def Exit():
        root.destroy()
    root=Tk(caption)
    root.title(caption)
    label=Label(root,text=MainLabel).pack()
    button=Button(root,text=ExitButton,command=Exit).pack()
    labellst=[]
    for l in labels:
        labellst.append(Label(root,text=l).pack())
    buttonlst=[]
    for b in buttons:
        buttonlst.append(Button(root,text=b).pack())
    if loop:
        root.mainloop()

def printxt(button):
        print(button.txt)
    
def eventwin(caption='',ExitButton='OK',label='please...',eventButton='event',command=msgwin,geometry=None,loop=True):
    root=Tk()
    root.title(caption)
    root.geometry(geometry)
    class button(Button):
        def __init__(self,master,text,command):
            super().__init__(root,text=text,command=lambda:command())
            self.txt=text
    def Exit():
        root.destroy()
    Exit=Button(root,text=label,command=Exit).pack()
    Main=button(root,eventButton,command).pack()
    if loop:
        root.mainloop()



#由 AmirSong(pypi)独家开发

#封装了许多常用组件

#包括 文件读写 列表等
#--------------------------
#Exclusively developed by AmirSong (pypi)

#It encapsulates many common components

#Including file read-write list, etc
#--------------------------


'''
    use it!!!
    
    >>>from mypybag import lists
    >>>l=adellist(1,'a',True,None)
    >>>l.get():
    [1,'a',True,None]
    >>>l.elements(0,1)
    [1]
    >>>l.add('hello')
    [1,'a',True,None,'hello']
    >>>a.pop()
    >>>a.get()
    [1,'a',True,None]
    >>>a.clear()
    >>>a.get()
    []
    >>>a.addelems(1,'1')
    >>>a.get()
    [1,'1']
    >>>a.remove(1)
    >>>a.get()
    ['1']
    >>>b=a.copy()
    >>>b
    ['1']

'''

__all__={
    'list':['adellist','readerlist'],
    'file':'File',
    '……':'……'
    }
    
import mypybag.lists
import mypybag.file
import mypybag.windows
import mypybag.thread
